package
Version:
v1.2.13
Opens a new window with list of versions in this module.
Published: Feb 15, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Post post lineworks message
type Body struct {
Text string `json:"text,omitempty"`
}
type Button struct {
Label string `json:"label,omitempty"`
URL string `json:"url,omitempty"`
}
Error lineworks webhook error
Error return error string
type Message struct {
Title string `json:"title,omitempty"`
Body Body `json:"body,omitzero"`
Button Button `json:"button,omitzero"`
}
Message lineworks message
Source Files
¶
Click to show internal directories.
Click to hide internal directories.